#
# spec file for package python-python-twitter
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%ifarch %{ix86}
# (type(resp[0]) is int) is not true for python 2.7, as it is long
%define skip -k 'not (testGetFollowerIDsPaged or testGetFollowersIDs or testGetRetweeters)'
%endif
%define oldpython python
Name:           python-python-twitter
Version:        3.5
Release:        lp152.1.1
Summary:        A Python wrapper around the Twitter API
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/bear/python-twitter
Source:         https://github.com/bear/python-twitter/archive/v%{version}.tar.gz
# https://github.com/bear/python-twitter/commit/f7eb83d9dca3ba0ee93e629ba5322732f99a3a30
# fix test for PostDirectMessage endpoint with new data
Patch0:         python-python-twitter-fix-test.patch
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-oauthlib}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
# /SECTION
BuildRequires:  fdupes
Requires:       python-future
Requires:       python-requests
Requires:       python-requests-oauthlib
%ifpython2
Provides:       %{oldpython}-twitter = %{version}
Obsoletes:      %{oldpython}-twitter < %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
This library provides a Python interface for the Twitter API <https://dev.twitter.com/>.

Twitter <http://twitter.com> provides a service that allows people to connect via the web, IM, and SMS. Twitter exposes a web services API
which can be used using this library.

%prep
%setup -q -n python-twitter-%{version}
%patch0 -p1
sed -i -e '/^#!\/usr\/bin\/env/d' twitter/*.py
echo %skip

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest %{?skip}

%files %{python_files}
%doc AUTHORS.rst CHANGES README.rst GAE.rst NOTICE
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu May  9 2019 pgajdos@suse.com
- version update to 3.5
  * Fix DM endpoint handling
- added patches
  fix test for PostDirectMessage endpoint with new data
  + python-python-twitter-fix-test.patch
- run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jun 10 2018 sebix+novell.com@sebix.at
- update to version 3.4.2:
  * Bugfixes:
  * Allow upload of GIFs with size up to 15mb. See #538
- update to version 3.4.1:
  * Bugfixes:
  * Fix an issue where :py:func:`twitter.twitter_utils.calc_expected_status_length` was failing for python 2 due to a failure to convert a bytes string to unicode. Github issue #546.
  * Documentation fix for :py:func:`twitter.api.Api.UsersLookup`. UsersLookup can take a string or a list and properly parses both of them now. Github issues #535 and #549.
  * Properly decode response content for :py:func:`twitter.twitter_utils.http_to_file`. Github issue #521.
  * Fix an issue with loading extended_tweet entities from Streaming API where tweets would be truncated when converting to a :py:class:`twitter.models.Status`. Github issues #491 and #506.
* Tue Feb 27 2018 sebix+novell.com@sebix.at
- Update to version 3.4. See changelog for all changes.
- convert to singlespec
- rename to python-python-twitter
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 1.1.0
  + Remove from ParseTweet the Python 2.7 only dict comprehension item
  + Fix GetListTimeline condition to enable owner_screen_name based fetching
  + Many fixes for readability and PEP8
  + Cleaning up some of the package importing. Only importing the functions that are needed
  + Also added first build of the sphinx documentation. Copied some info from the readme to the index page
  + Added lines to setup.py to help the user troubleshoot install problems. #109
  + Removed the OAuth2 lines from the readme
  + Removed OAuth2 library requirements
  + Added GetListMembers()
- Changes from 1.0.1
  + added README bit about Python version requirement
- Changes from 1.0
  + removed doc directory until we can update docs for v1.1 API
  + added to package MANIFEST.in the testdata directory
- Changes from 1.0rc1
  + The library is now only for Twitter API v1.1
- Changes from 0.8.7
  + removed GetPublicTimeline from the docs so as to stop confusing
    new folks since it was the first example given
* Mon Feb 11 2013 p.drouand@gmail.com
- Update to 0.8.6
  * update requirements.txt to remove distribute reference
    github commit 3b9214a879e5fbd03036a7d4ae86babc03784846
  * Merge pull request #33 from iElectric/profile_image_url_https
    github commit 67cbb8390701c945a48094795474ca485f092049
  * Change User.NewFromJsonDict so that it will pull from either
    profile_image_url_https or profile_image_url to keep older code
    working properly if they have stored older json data
- Clean the specfile
* Wed May 25 2011 saschpe@suse.de
- Update to version 0.8.2
  * Fixed issues 193, 181, 182, 137, 93, 190, 166, 187, 184, 185, 183
- Corrected shebang line for *.py files to use the correct interpreter
* Fri Apr 15 2011 saschpe@suse.de
- Update to version 0.8.1
- Spec file cleanup:
  - Added documentation
  - Set to noarch
  - Set license to APLv2
* Mon Sep 21 2009 alexandre@exatati.com.br
- Included require in the spec file.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (0.6) for openSUSE.
